pub struct SecretMapping {
pub var: String,
pub value: String,
}Expand description
Mapping from environment variable name to the real secret value. The sandbox will inject a masked token into the subprocess env and the proxy will replace that token with this value in outgoing HTTP requests. Real values must not contain CR, LF, or NUL (validated at run time).
Fields
var: Stringvalue: StringImplementations